store

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (

	// ShortFlags is the unified lookup, composed from all families.
	ShortFlags = mergeFlagDefinitions(
		workerPoolFlags,
		previewFlags,
		filterFlags,
		profileFlags,
		i18nFlags,
		depthFlags,
		samplingFlags,
		interactionFlags,
	)
)

Functions

This section is empty.

Types

type AlloyFilterParameterSet

type AlloyFilterParameterSet struct {
	ParameterSetWithOverrides
	FilesExGlob string
	FoldersGlob string
}

AlloyFilterParameterSet represents a family of parameters that can be used to accept file and folder filters. Files are represented by an extended glob and folders by a regular glob.

func (*AlloyFilterParameterSet) BindAll

func (f *AlloyFilterParameterSet) BindAll(
	parent *assist.ParamSet[AlloyFilterParameterSet],
	flagSet ...*pflag.FlagSet,
)

type CascadeParameterSet

type CascadeParameterSet struct {
	ParameterSetWithOverrides
	Depth     uint
	NoRecurse bool
}

func (*CascadeParameterSet) BindAll

func (f *CascadeParameterSet) BindAll(
	parent *assist.ParamSet[CascadeParameterSet],
	flagSet ...*pflag.FlagSet,
)

type CliInteractionParameterSet

type CliInteractionParameterSet struct {
	ParameterSetWithOverrides
	IsTUI bool
}

func (*CliInteractionParameterSet) BindAll

type FilesFilterParameterSet

type FilesFilterParameterSet struct {
	ParameterSetWithOverrides
	Files      string
	FilesGlob  string
	FilesRexEx string
}

FilesFilterParameterSet represents a family of parameters that can be used to accept a file filter. files is considered the default as it is the most user friendly to use, as a glob is easier and more intuitive to use on the command line and supports (with te help of a delimiter) multiple extensions to be specified with a csv, in contrast to a regular glob.

func (*FilesFilterParameterSet) BindAll

func (f *FilesFilterParameterSet) BindAll(
	parent *assist.ParamSet[FilesFilterParameterSet],
	flagSet ...*pflag.FlagSet,
)

type FoldersFilterParameterSet

type FoldersFilterParameterSet struct {
	ParameterSetWithOverrides
	FoldersGlob  string
	FoldersRexEx string
}

FoldersFilterParameterSet represents a family of parameters that can be used to accept a folder filter. In contrast to files, the folders family does not include an extended glob because folders do not contain extensions, so the regular glob will suffice.

func (*FoldersFilterParameterSet) BindAll

func (f *FoldersFilterParameterSet) BindAll(
	parent *assist.ParamSet[FoldersFilterParameterSet],
	flagSet ...*pflag.FlagSet,
)

type I18nParameterSet

type I18nParameterSet struct {
	ParameterSetWithOverrides
	Language string
}

func (*I18nParameterSet) BindAll

func (f *I18nParameterSet) BindAll(
	parent *assist.ParamSet[I18nParameterSet],
	flagSet ...*pflag.FlagSet,
)

type ParameterSetWithOverrides

type ParameterSetWithOverrides struct {
	Overrides []assist.ShortFlagOverride
}

ParameterSetWithOverrides allows the client to define short code overrides applicable for the host parameter set.

type PolyFilterParameterSet

type PolyFilterParameterSet struct {
	ParameterSetWithOverrides
	FilesExGlob  string
	FilesRexEx   string
	FoldersGlob  string
	FoldersRexEx string
}

PolyFilterParameterSet represents a family of parameters that can be used to accept file and folder filters. This family is composed of files and filters. For files, either an extended glob or regex is supported. For folders, either a regular glob or regex is supported.

func (*PolyFilterParameterSet) BindAll

func (f *PolyFilterParameterSet) BindAll(
	parent *assist.ParamSet[PolyFilterParameterSet],
	flagSet ...*pflag.FlagSet,
)

type PreviewParameterSet

type PreviewParameterSet struct {
	ParameterSetWithOverrides
	DryRun bool
}

func (*PreviewParameterSet) BindAll

func (f *PreviewParameterSet) BindAll(
	parent *assist.ParamSet[PreviewParameterSet],
	flagSet ...*pflag.FlagSet,
)

type ProfileParameterSet

type ProfileParameterSet struct {
	ParameterSetWithOverrides
	Profile string
	Scheme  string
}

func (*ProfileParameterSet) BindAll

func (f *ProfileParameterSet) BindAll(
	parent *assist.ParamSet[ProfileParameterSet],
	flagSet ...*pflag.FlagSet,
)

type SamplingParameterSet

type SamplingParameterSet struct {
	ParameterSetWithOverrides
	IsSampling bool
	NoFiles    uint
	NoFolders  uint
	Last       bool
}

func (*SamplingParameterSet) BindAll

func (f *SamplingParameterSet) BindAll(
	parent *assist.ParamSet[SamplingParameterSet],
	flagSet ...*pflag.FlagSet,
)

type TextualInteractionParameterSet

type TextualInteractionParameterSet struct {
	ParameterSetWithOverrides
	IsNoTui bool
}

func (*TextualInteractionParameterSet) BindAll

type WorkerPoolParameterSet

type WorkerPoolParameterSet struct {
	ParameterSetWithOverrides
	CPU       bool
	NoWorkers int
}

func (*WorkerPoolParameterSet) BindAll

func (f *WorkerPoolParameterSet) BindAll(
	parent *assist.ParamSet[WorkerPoolParameterSet],
	flagSet ...*pflag.FlagSet,
)

Jump to